@@ -1,7 +1,7 @@
 package Sidef {
 
     use 5.014;
-    our $VERSION = '2.20';
+    our $VERSION = '2.21';
 
     our $SPACES      = 0;    # the current number of spaces
     our $SPACES_INCR = 4;    # the number of spaces incrementor
@@ -11,9 +11,8 @@ package Sidef {
 
     our %EVALS;              # will contain info required for eval()
 
-    #use Math::BigInt qw(try GMP);
-    #use Math::BigRat qw(try GMP);
-    #use Math::BigFloat qw(try GMP);
+    use Sidef::Types::Bool::Bool;
+    use Sidef::Types::Number::Number;
 
     sub new {
         bless {}, __PACKAGE__;
