@@ -355,7 +355,15 @@ HEADER
 
     sub _dump_indices {
         my ($self, $array) = @_;
-        '[' . join(', ', map { ref($_) ? ($self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_})) : $_ } @{$array}) . ']';
+        '[' . join(
+            ', ',
+            map {
+                    ref($_) eq 'Sidef::Types::Number::Number' ? $_->_get_double
+                  : ref($_) ? ($self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_}))
+                  : $_
+              } @{$array}
+          )
+          . ']';
     }
 
     sub _dump_unpacked_indices {
@@ -377,7 +385,16 @@ HEADER
 
     sub _dump_lookups {
         my ($self, $array) = @_;
-        '{' . join(', ', map { ref($_) ? ($self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_})) : $_ } @{$array}) . '}';
+        '{' . join(
+            ', ',
+            map {
+                (ref($_) eq 'Sidef::Types::String::String' or ref($_) eq 'Sidef::Types::Number::Number')
+                  ? $self->_dump_string($_->get_value)
+                  : ref($_) ? ($self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_}))
+                  : $_
+              } @{$array}
+          )
+          . '}';
     }
 
     sub _dump_unpacked_lookups {
@@ -570,6 +587,12 @@ HEADER
                               . "\$$obj->{name}$refaddr->call(\$self, Sidef::Types::String::String->new(\$class), Sidef::Types::String::String->new(\$method), \@_) }";
                         }
 
+                        # Anonymous method
+                        elsif ($obj->{name} eq '__ANON__') {
+                            ## don't add anonymous methods to the class,
+                            ## but allow them to be defined and used freely
+                        }
+
                         # Other methods
                         else {
                             $code .= ";\n"
@@ -685,6 +708,7 @@ HEADER
                 local $self->{package_name}     = $package_name;
                 local $self->{inherit}          = $obj->{inherit} if exists $obj->{inherit};
                 local $self->{class_vars}       = $obj->{vars} if exists $obj->{vars};
+                local $self->{class_struct}     = $obj->{struct} if exists $obj->{struct};
                 local $self->{class_attributes} = $obj->{attributes} if exists $obj->{attributes};
                 local $self->{ref_class}        = 1 if ref($obj->{name});
                 $code .= $self->deparse_expr({self => $block});
@@ -733,11 +757,14 @@ HEADER
                             push @{$self->{function_declarations}}, [$refaddr, "my \$new$refaddr;"];
 
                             $Sidef::SPACES += $Sidef::SPACES_INCR;
-                            $code .= $self->_dump_sub_init_vars(@{$self->{class_vars}})
+                            $code .= $self->_dump_sub_init_vars(@{$self->{class_vars}},
+                                                                (map { @{$_->{vars}} } @{$self->{class_struct}}))
                               . $self->_dump_class_attributes(@{$self->{class_attributes}});
 
                             $code .= (' ' x $Sidef::SPACES) . 'my $self = bless {';
-                            foreach my $var (@{$self->{class_vars}}, map { @{$_->{vars}} } @{$self->{class_attributes}}) {
+                            foreach my $var (@{$self->{class_vars}},
+                                             (map { @{$_->{vars}} } @{$self->{class_attributes}}),
+                                             (map { @{$_->{vars}} } @{$self->{class_struct}})) {
                                 $code .= qq{"\Q$var->{name}\E"=>} . $self->_dump_var($var) . ', ';
                             }
 
@@ -751,7 +778,7 @@ HEADER
                             $Sidef::SPACES -= $Sidef::SPACES_INCR;
                             $code .=
                                 (" " x $Sidef::SPACES . "}") . ', '
-                              . $self->_dump_var_attr(@{$self->{class_vars}})
+                              . $self->_dump_var_attr(@{$self->{class_vars}}, map { @{$_->{vars}} } @{$self->{class_struct}})
                               . ", type => "
                               . $self->_dump_string('class')
                               . ", name => "
@@ -763,7 +790,9 @@ HEADER
                               . $self->_dump_string("$self->{package_name}\::call")
                               . "} = sub { CORE::shift(\@_); \$new$refaddr->call(\@_) } };\n";
 
-                            foreach my $var (@{$self->{class_vars}}, map { @{$_->{vars}} } @{$self->{class_attributes}}) {
+                            foreach my $var (@{$self->{class_vars}},
+                                             (map { @{$_->{vars}} } @{$self->{class_attributes}}),
+                                             (map { @{$_->{vars}} } @{$self->{class_struct}})) {
                                 $code .=
                                   (' ' x $Sidef::SPACES) . qq{sub $var->{name} : lvalue { \$_[0]->{"\Q$var->{name}\E"} }\n};
                             }
@@ -983,7 +1012,8 @@ HEADER
                 'do{ if (defined(my '
               . $dvar . '='
               . $self->deparse_args($obj->{expr}) . ')) '
-              . $self->deparse_bare_block($obj->{block}{code}) . '}';
+              . $self->deparse_bare_block($obj->{block}{code})
+              . ' else { } }';
         }
         elsif ($ref eq 'Sidef::Types::Block::Gather') {
             $code =
@@ -1155,7 +1185,8 @@ HEADER
         }
         elsif ($ref eq 'Sidef::Meta::Warning') {
             my @args = $self->deparse_args($obj->{arg});
-            $code = qq~Sidef::Types::Bool::Bool->new(CORE::warn(@args, " at \Q$obj->{file}\E line $obj->{line}\\n"))~;
+            $code = qq~((CORE::warn(@args, " at \Q$obj->{file}\E line $obj->{line}\\n")) ? ~
+              . qq~(Sidef::Types::Bool::Bool::FALSE) : (Sidef::Types::Bool::Bool::TRUE))~;
         }
         elsif ($ref eq 'Sidef::Object::Object') {
             $code = $self->make_constant($ref, 'new', "Object$refaddr");
@@ -1337,21 +1368,24 @@ HEADER
                     # != and == methods
                     if ($method eq '==' or $method eq '!=') {
                         $code =
-                            'Sidef::Types::Bool::Bool->new('
+                            '(('
                           . ($method eq '!=' ? 'CORE::not ' : '') . 'do{'
                           . $code
                           . '} eq do{'
-                          . $self->deparse_args(@{$call->{arg}}) . '})';
+                          . $self->deparse_args(@{$call->{arg}})
+                          . '}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
                         next;
                     }
 
                     # <=> method
                     if ($method eq '<=>') {
                         $code =
-                            'Sidef::Types::Number::Number->new(do{'
+                            '((Sidef::Types::Number::Number::ZERO,'
+                          . 'Sidef::Types::Number::Number::ONE,'
+                          . 'Sidef::Types::Number::Number::MONE)[do{'
                           . $code
                           . '} cmp do {'
-                          . $self->deparse_args(@{$call->{arg}}) . '})';
+                          . $self->deparse_args(@{$call->{arg}}) . '}])';
                         next;
                     }
 
@@ -1359,18 +1393,21 @@ HEADER
                     if ($method eq '~~' or $method eq '!~') {
                         $self->top_add(qq{use experimental 'smartmatch';\n});
                         $code =
-                            'Sidef::Types::Bool::Bool->new('
+                            '(('
                           . ($method eq '!~' ? 'CORE::not ' : '') . 'do{'
                           . $code
                           . '} ~~ do{'
-                          . $self->deparse_args(@{$call->{arg}}) . '})';
+                          . $self->deparse_args(@{$call->{arg}})
+                          . '}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
                         next;
                     }
 
                     # ! prefix-unary
                     if ($ref eq 'Sidef::Object::Unary') {
                         if ($method eq '!') {
-                            $code = 'Sidef::Types::Bool::Bool->new(!do{' . $self->deparse_args(@{$call->{arg}}) . '})';
+                            $code = '(do{'
+                              . $self->deparse_args(@{$call->{arg}})
+                              . '} ? (Sidef::Types::Bool::Bool::FALSE) : (Sidef::Types::Bool::Bool::TRUE))';
                             next;
                         }
 
@@ -1395,12 +1432,18 @@ HEADER
                         }
 
                         if ($method eq 'say' or $method eq '>') {
-                            $code = 'Sidef::Types::Bool::Bool->new(CORE::say' . $self->deparse_args(@{$call->{arg}}) . ')';
+                            $code =
+                                '((CORE::say'
+                              . $self->deparse_args(@{$call->{arg}})
+                              . ') ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
                             next;
                         }
 
                         if ($method eq 'print' or $method eq '>>') {
-                            $code = 'Sidef::Types::Bool::Bool->new(CORE::print' . $self->deparse_args(@{$call->{arg}}) . ')';
+                            $code =
+                                '((CORE::print'
+                              . $self->deparse_args(@{$call->{arg}})
+                              . ') ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
                             next;
                         }
                     }
