@@ -2,6 +2,7 @@ package Sidef::Object::Object {
 
     use 5.014;
     require Scalar::Util;
+    use Sidef::Types::Bool::Bool;
 
     use overload
       q{~~}   => \&{__PACKAGE__ . '::' . '~~'},
@@ -61,13 +62,17 @@ package Sidef::Object::Object {
     }
 
     sub say {
-        Sidef::Types::Bool::Bool->new(CORE::say @_);
+        (CORE::say @_)
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     *println = \&say;
 
     sub print {
-        Sidef::Types::Bool::Bool->new(CORE::print @_);
+        (CORE::print @_)
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub method {
@@ -105,15 +110,20 @@ package Sidef::Object::Object {
 
     sub respond_to {
         my ($self, $method) = @_;
-        Sidef::Types::Bool::Bool->new($self->can($method));
+        ($self->can($method))
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_a {
         my ($self, $obj) = @_;
-        Sidef::Types::Bool::Bool->new($self->SUPER::isa(CORE::ref($obj) || $obj));
+        ($self->SUPER::isa(CORE::ref($obj) || $obj))
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
-    *is_an = \&is_a;
+    *is_an   = \&is_a;
+    *kind_of = \&is_a;
 
     sub parent_classes {
         my ($obj) = @_;
@@ -214,7 +224,9 @@ package Sidef::Object::Object {
 
         # Logical XOR
         *{__PACKAGE__ . '::' . '^'} = sub {
-            Sidef::Types::Bool::Bool->new($_[0] xor $_[1]);
+            ($_[0] xor $_[1])
+              ? (Sidef::Types::Bool::Bool::TRUE)
+              : (Sidef::Types::Bool::Bool::FALSE);
         };
 
         # Defined-OR
@@ -364,7 +376,9 @@ package Sidef::Object::Object {
                 return $second->contains($first);
             }
 
-            Sidef::Types::Bool::Bool->new($first eq $second);
+            ($first eq $second)
+              ? (Sidef::Types::Bool::Bool::TRUE)
+              : (Sidef::Types::Bool::Bool::FALSE);
         };
 
         # Negation of smart match
