@@ -94,7 +94,12 @@ package Sidef::Types::Block::Block {
                 }
                 elsif (exists $seen{$var->{name}}) {
                     if (exists $var->{where_block}) {
-                        $var->{where_block}($seen{$var->{name}}) or next OUTER;
+                        (
+                         exists($var->{slurpy})
+                         ? $var->{where_block}(Sidef::Types::Array::Array->new(@{$seen{$var->{name}}}))
+                         : $var->{where_block}($seen{$var->{name}})
+                        )
+                          or next OUTER;
                     }
                     elsif (exists $var->{where_expr}) {
                         $var->{where_expr} eq $seen{$var->{name}} or next OUTER;
@@ -277,24 +282,24 @@ package Sidef::Types::Block::Block {
         $bool;
     }
 
-    #~ sub fork {
-    #~ my ($self) = @_;
+    sub ffork {
+        my ($self, @args) = @_;
 
-    #~ state $x = require Storable;
-    #~ open(my $fh, '+>', undef);    # an anonymous temporary file
-    #~ my $fork = Sidef::Types::Block::Fork->new(fh => $fh);
+        state $x = require Storable;
+        open(my $fh, '+>', undef);    # an anonymous temporary file
+        my $fork = Sidef::Types::Block::Fork->new(fh => $fh);
 
-    #~ my $pid = fork() // die "[FATAL ERROR]: cannot fork";
-    #~ if ($pid == 0) {
-    #~ srand();
-    #~ my $obj = $self->{code}->();
-    #~ ref($obj) && Storable::store_fd($obj, $fh);
-    #~ exit 0;
-    #~ }
+        my $pid = fork() // die "[ERROR]: Cannot fork";
+        if ($pid == 0) {
+            srand();
+            my $obj = $self->call(@args);
+            ref($obj) && Storable::store_fd($obj, $fh);
+            exit 0;
+        }
 
-    #~ $fork->{pid} = $pid;
-    #~ $fork;
-    #~ }
+        $fork->{pid} = $pid;
+        $fork;
+    }
 
     sub fork {
         my ($self) = @_;
@@ -313,14 +318,23 @@ package Sidef::Types::Block::Block {
     }
 
     sub thread {
-        my ($self) = @_;
+        my ($self, @args) = @_;
         state $x = do {
-            require threads;
+            eval { require forks; } // do {
+                warn "[WARN] Can't load the `forks` module. Using `threads` instead...\n";
+                require threads;
+            };
             *threads::get  = \&threads::join;
             *threads::wait = \&threads::join;
             1;
         };
-        threads->create(sub { $self->{code}->() });
+        threads->create(
+                        {
+                         'context' => 'list',
+                         'exit'    => 'thread_only'
+                        },
+                        sub { $self->call(@args) }
+                       );
     }
 
     *thr = \&thread;
