@@ -11,6 +11,8 @@ package Sidef::Types::Hash::Hash {
       q{bool} => sub { scalar(CORE::keys %{$_[0]}) },
       q{""}   => \&dump;
 
+    use Sidef::Types::Bool::Bool;
+
     sub new {
         my ($class, %pairs) = @_;
         bless \%pairs, __PACKAGE__;
@@ -71,23 +73,24 @@ package Sidef::Types::Hash::Hash {
         Sidef::Types::Number::Number->new(scalar CORE::keys %$self);
     }
 
-    *len = \&length;
+    *len  = \&length;
+    *size = \&length;
 
     sub eq {
         my ($self, $obj) = @_;
 
         (%$self eq %{$obj})
-          or return Sidef::Types::Bool::Bool->false;
+          or return (Sidef::Types::Bool::Bool::FALSE);
 
         while (my ($key, $value) = each %$self) {
             exists($obj->{$key})
-              or return Sidef::Types::Bool::Bool->false;
+              or return (Sidef::Types::Bool::Bool::FALSE);
 
             $value eq $obj->{$key}
-              or return Sidef::Types::Bool::Bool->false;
+              or return (Sidef::Types::Bool::Bool::FALSE);
         }
 
-        Sidef::Types::Bool::Bool->true;
+        (Sidef::Types::Bool::Bool::TRUE);
     }
 
     sub ne {
@@ -100,15 +103,15 @@ package Sidef::Types::Hash::Hash {
 
         if (ref($self) ne ref($obj)
             or %$self ne %{$obj}) {
-            return Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         while (my ($key) = each %$self) {
             exists($obj->{$key})
-              or return Sidef::Types::Bool::Bool->false;
+              or return (Sidef::Types::Bool::Bool::FALSE);
         }
 
-        Sidef::Types::Bool::Bool->true;
+        (Sidef::Types::Bool::Bool::TRUE);
     }
 
     sub append {
@@ -141,7 +144,7 @@ package Sidef::Types::Hash::Hash {
         $self->new(%hash);
     }
 
-    *map_values = \&map_val;
+    *map_v = \&map_val;
 
     sub map {
         my ($self, $code) = @_;
@@ -155,21 +158,53 @@ package Sidef::Types::Hash::Hash {
         $self->new(%hash);
     }
 
-    sub select {
-        my ($self, $code) = @_;
+    *map_kv = \&map;
+
+    sub grep {
+        my ($self, $obj) = @_;
 
         my %hash;
-        foreach my $key (CORE::keys %$self) {
-            my $value = $self->{$key};
-            if ($code->run(Sidef::Types::String::String->new($key), $value)) {
-                $hash{$key} = $value;
+        if (ref($obj) eq 'Sidef::Types::Regex::Regex') {
+            my $re = $obj->{regex};
+            my @keys = grep { $_ =~ $re } CORE::keys(%$self);
+            @hash{@keys} = @$self{@keys};
+        }
+        else {
+            foreach my $key (CORE::keys %$self) {
+                my $value = $self->{$key};
+                if ($obj->run(Sidef::Types::String::String->new($key), $value)) {
+                    $hash{$key} = $value;
+                }
             }
         }
 
         $self->new(%hash);
     }
 
-    *grep = \&select;
+    *grep_kv = \&grep;
+    *select  = \&grep;
+
+    sub grep_val {
+        my ($self, $obj) = @_;
+
+        my %hash;
+        if (ref($obj) eq 'Sidef::Types::Regex::Regex') {
+            my @keys = grep { $obj->match($self->{$_}) } CORE::keys(%$self);
+            @hash{@keys} = @$self{@keys};
+        }
+        else {
+            foreach my $key (CORE::keys %$self) {
+                my $value = $self->{$key};
+                if ($obj->run($value)) {
+                    $hash{$key} = $value;
+                }
+            }
+        }
+
+        $self->new(%hash);
+    }
+
+    *grep_v = \&grep_val;
 
     sub count {
         my ($self, $code) = @_;
@@ -311,7 +346,7 @@ package Sidef::Types::Hash::Hash {
 
     sub exists {
         my ($self, $key) = @_;
-        Sidef::Types::Bool::Bool->new(CORE::exists $self->{$key});
+        (CORE::exists $self->{$key}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     *has_key  = \&exists;
