@@ -15,7 +15,9 @@ package Sidef::Types::Number::Complex {
 
     require Math::MPC;
     require Math::MPFR;
-    require Sidef::Types::Number::Number;
+
+    use Sidef::Types::Bool::Bool;
+    use Sidef::Types::Number::Number;
 
     our $ROUND = Math::MPC::MPC_RNDNN();
 
@@ -38,7 +40,28 @@ package Sidef::Types::Number::Complex {
             }
         }
         elsif (index(ref($x), 'Sidef::') == 0) {
-            $x = $x->get_value;
+            $x = "$x";
+            if ($x eq 'i' or $x eq '+i') {
+                return __PACKAGE__->new(__PACKAGE__->new(0, 1), $y);
+            }
+            elsif ($x eq '-i') {
+                return __PACKAGE__->new(__PACKAGE__->new(0, -1), $y);
+            }
+            elsif (substr($x, -1) eq 'i') {
+                if ($x =~ /^(.+?)([+-].*?)i\z/) {
+                    my ($re, $im) = ($1, $2);
+                    if ($im eq '+') {
+                        $im = 1;
+                    }
+                    elsif ($im eq '-') {
+                        $im = -1;
+                    }
+                    return __PACKAGE__->new(__PACKAGE__->new($re, $im), $y);
+                }
+                else {
+                    return __PACKAGE__->new(__PACKAGE__->new(0, $x), $y);
+                }
+            }
         }
 
         if (not defined($y)) {
@@ -59,7 +82,28 @@ package Sidef::Types::Number::Complex {
             return $y->add(__PACKAGE__->new($x));
         }
         elsif (index(ref($y), 'Sidef::') == 0) {
-            $y = $y->get_value;
+            $y = "$y";
+            if ($y eq 'i' or $y eq '+i') {
+                return __PACKAGE__->new($x, __PACKAGE__->new(0, 1));
+            }
+            elsif ($y eq '-i') {
+                return __PACKAGE__->new($x, __PACKAGE__->new(0, -1));
+            }
+            elsif (substr($y, -1) eq 'i') {
+                if ($y =~ /^(.+?)([+-].*?)i\z/) {
+                    my ($re, $im) = ($1, $2);
+                    if ($im eq '+') {
+                        $im = 1;
+                    }
+                    elsif ($im eq '-') {
+                        $im = -1;
+                    }
+                    return __PACKAGE__->new($x, __PACKAGE__->new($re, $im));
+                }
+                else {
+                    return __PACKAGE__->new($x, __PACKAGE__->new(0, $y));
+                }
+            }
         }
 
         my $r = Math::MPC::Rmpc_init2($PREC);
@@ -711,10 +755,10 @@ package Sidef::Types::Number::Complex {
         }
 
         if (Math::MPC::Rmpc_cmp($$x, $$y) == 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -729,10 +773,10 @@ package Sidef::Types::Number::Complex {
         }
 
         if (Math::MPC::Rmpc_cmp($$x, $$y) == 0) {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
     }
 
@@ -838,17 +882,17 @@ package Sidef::Types::Number::Complex {
         Math::MPC::Rmpc_imag($im, ${$_[0]}, $ROUND);
 
         if (Math::MPFR::Rmpfr_sgn($im) != 0) {
-            return state $z = Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $re = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_real($re, ${$_[0]}, $ROUND);
 
         if (Math::MPFR::Rmpfr_integer_p($re)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -859,23 +903,23 @@ package Sidef::Types::Number::Complex {
         Math::MPC::Rmpc_imag($im, ${$_[0]}, $ROUND);
 
         if (Math::MPFR::Rmpfr_sgn($im) == 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_nan {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_inf {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_ninf {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     {
