@@ -2,7 +2,6 @@ package Sidef::Types::Number::Ninf {
 
     use utf8;
     use 5.014;
-    require Math::GMPq;
 
     use parent qw(
       Sidef::Object::Object
@@ -22,14 +21,6 @@ package Sidef::Types::Number::Ninf {
         bless \$r, __PACKAGE__;
     };
 
-    state $ZERO = $Sidef::Types::Number::Number::ZERO;
-    state $ONE  = $Sidef::Types::Number::Number::ONE;
-    state $MONE = $Sidef::Types::Number::Number::MONE;
-
-    if (not defined $ZERO or not defined $ONE or not defined $MONE) {
-        die "Fatal error: can't load the Ninf class!";
-    }
-
     sub new { $NINF }
 
     sub get_value { -'Inf' }
@@ -51,7 +42,7 @@ package Sidef::Types::Number::Ninf {
     sub mul {
         my ($x, $y) = @_;
         ref($y) eq __PACKAGE__ and return $x->neg;
-        $y->is_neg ? $x->neg : $x;
+        $y->is_neg ? $x->neg : $x->is_pos ? $x : nan();
     }
 
     *imul = \&mul;
@@ -67,7 +58,7 @@ package Sidef::Types::Number::Ninf {
     *idiv = \&div;
 
     sub is_pos {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     *is_nan    = \&is_pos;
@@ -83,7 +74,7 @@ package Sidef::Types::Number::Ninf {
     *is_real   = \&is_pos;
 
     sub is_neg {
-        state $x = Sidef::Types::Bool::Bool->true;
+        (Sidef::Types::Bool::Bool::TRUE);
     }
 
     *is_inf  = \&is_neg;
@@ -175,6 +166,7 @@ package Sidef::Types::Number::Ninf {
     *shift_left  = \&ninf;
     *shift_right = \&ninf;
     *rand_int    = \&ninf;
+    *irand       = \&ninf;
     *rand        = \&ninf;
     *rad2deg     = \&ninf;
     *rad2grad    = \&ninf;
@@ -182,11 +174,10 @@ package Sidef::Types::Number::Ninf {
     *deg2rad     = \&ninf;
     *grad2rad    = \&ninf;
     *grad2deg    = \&ninf;
-    *commify     = \&ninf;
 
     sub max { $_[1] }
 
-    sub zero { $ZERO }
+    sub zero { (Sidef::Types::Number::Number::ZERO) }
 
     *inv   = \&zero;
     *sin   = \&zero;
@@ -273,7 +264,7 @@ package Sidef::Types::Number::Ninf {
     #
     ## tanh(-inf) = -1
     #
-    sub tanh { $MONE }
+    sub tanh { (Sidef::Types::Number::Number::MONE) }
 
     *coth = \&tanh;
     *erf  = \&tanh;
@@ -288,7 +279,10 @@ package Sidef::Types::Number::Ninf {
     #
     sub pow {
         my ($x, $y) = @_;
-        $y->is_neg ? $ZERO : $y->is_zero ? $ONE : $y->is_even ? $x->neg : $x;
+            $y->is_neg  ? (Sidef::Types::Number::Number::ZERO)
+          : $y->is_zero ? (Sidef::Types::Number::Number::ONE)
+          : $y->is_even ? $x->neg
+          :               $x;
     }
 
     #
@@ -299,7 +293,9 @@ package Sidef::Types::Number::Ninf {
     #
     sub binomial {
         my ($x, $y) = @_;
-        ref($y) eq 'Sidef::Types::Number::Inf' ? $ONE : $y->is_neg ? $ZERO : $x;
+        ref($y) eq 'Sidef::Types::Number::Inf' ? (Sidef::Types::Number::Number::ONE)
+          : $y->is_neg                         ? (Sidef::Types::Number::Number::ZERO)
+          :                                      $x;
     }
 
     *nok = \&binomial;
@@ -311,56 +307,85 @@ package Sidef::Types::Number::Ninf {
     sub eq {
         my ($x, $y) = @_;
         if (ref($y) eq __PACKAGE__) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub ne {
         my ($x, $y) = @_;
         if (ref($y) eq __PACKAGE__) {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
     }
 
     sub gt {
-        state $z = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub ge {
         my ($x, $y) = @_;
         if (ref($y) eq __PACKAGE__) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub lt {
         my ($x, $y) = @_;
         if (ref($y) eq __PACKAGE__) {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
     }
 
     sub le {
-        state $z = Sidef::Types::Bool::Bool->true;
+        (Sidef::Types::Bool::Bool::TRUE);
     }
 
     sub cmp {
         my ($x, $y) = @_;
-        ref($y) eq __PACKAGE__ ? $ZERO : $MONE;
+        ref($y) eq __PACKAGE__ ? (Sidef::Types::Number::Number::ZERO) : (Sidef::Types::Number::Number::MONE);
     }
 
+    sub i {
+        my ($x) = @_;
+        Sidef::Types::Number::Complex->new(0, $x);
+    }
+
+    sub dump {
+        Sidef::Types::String::String->new('-Inf');
+    }
+
+    *commify = \&dump;
+
+    sub numerator {
+        Sidef::Types::Number::Number::MONE;
+    }
+
+    *nu = \&numerator;
+
+    sub denominator {
+        Sidef::Types::Number::Number::ZERO;
+    }
+
+    *de = \&denominator;
+
+    sub parts {
+        (Sidef::Types::Number::Number::MONE, Sidef::Types::Number::Number::ZERO);
+    }
+
+    *nude = \&parts;
+
     {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '+'}   = \&add;
@@ -391,6 +416,7 @@ package Sidef::Types::Number::Ninf {
         *{__PACKAGE__ . '::' . '<=>'} = \&cmp;
         *{__PACKAGE__ . '::' . '!'}   = \&factorial;
         *{__PACKAGE__ . '::' . '%%'}  = \&is_div;
+        *{__PACKAGE__ . '::' . '~'}   = \&not;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
         *{__PACKAGE__ . '::' . '//'}  = \&div;
