@@ -3,9 +3,9 @@ package Sidef::Types::Number::Number {
     use utf8;
     use 5.014;
 
-    require Math::GMPq;
-    require Math::GMPz;
-    require Math::MPFR;
+    use Math::GMPq qw();
+    use Math::GMPz qw();
+    use Math::MPFR qw();
 
     use parent qw(
       Sidef::Object::Object
@@ -17,15 +17,19 @@ package Sidef::Types::Number::Number {
 
     our $GET_PERL_VALUE = 0;
 
-    our $ONE  = bless(\Math::GMPq->new(1),  __PACKAGE__);
-    our $ZERO = bless(\Math::GMPq->new(0),  __PACKAGE__);
-    our $MONE = bless(\Math::GMPq->new(-1), __PACKAGE__);
+    use constant {
+                  ONE  => bless(\Math::GMPq->new(1),  __PACKAGE__),
+                  ZERO => bless(\Math::GMPq->new(0),  __PACKAGE__),
+                  MONE => bless(\Math::GMPq->new(-1), __PACKAGE__),
+                 };
 
     use overload
       q{bool} => sub { Math::GMPq::Rmpq_sgn(${$_[0]}) != 0 },
       q{0+}   => sub { Math::GMPq::Rmpq_get_d(${$_[0]}) },
       q{""}   => \&get_value;
 
+    use Sidef::Types::Bool::Bool;
+
     sub _load_bigrat {
         state $bigrat = do {
             require Math::BigRat;
@@ -205,6 +209,10 @@ package Sidef::Types::Number::Number {
         Math::GMPq::Rmpq_get_str(${$_[0]}, 10);
     }
 
+    sub _get_double {
+        Math::GMPq::Rmpq_get_d(${$_[0]});
+    }
+
     #
     ## Constants
     #
@@ -312,7 +320,7 @@ package Sidef::Types::Number::Number {
         }
 
         if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return $ZERO;
+            return (ZERO);
         }
 
         _valid($y);
@@ -337,7 +345,8 @@ package Sidef::Types::Number::Number {
         }
 
         if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return (Math::GMPq::Rmpq_sgn($$x) < 0 ? $y->neg : $y);
+            my $sign = Math::GMPq::Rmpq_sgn($$x);
+            return ($sign < 0 ? $y->neg : $sign > 0 ? $y : nan());
         }
 
         _valid($y);
@@ -403,11 +412,11 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return $ONE;
+            return (ONE);
         }
 
         _valid($y);
-        return $x->pow($ONE->div($y));
+        return $x->pow((ONE)->div($y));
     }
 
     sub sqr {
@@ -426,19 +435,19 @@ package Sidef::Types::Number::Number {
             return $y;
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return $ZERO;
+            return (ZERO);
         }
 
         _valid($y);
 
-        if (Math::GMPq::Rmpq_sgn($$y) >= 0 and _is_int($$x) and _is_int($$y)) {
+        if (Math::GMPq::Rmpq_sgn($$y) >= 0 and Math::GMPq::Rmpq_integer_p($$x) and Math::GMPq::Rmpq_integer_p($$y)) {
             my $z = Math::GMPz::Rmpz_init();
             Math::GMPz::Rmpz_set_q($z, $$x);
             Math::GMPz::Rmpz_pow_ui($z, $z, Math::GMPq::Rmpq_get_d($$y));
             return _mpz2rat($z);
         }
 
-        if (Math::GMPq::Rmpq_sgn($$x) < 0 and CORE::not _is_int($$y)) {
+        if (Math::GMPq::Rmpq_sgn($$x) < 0 and CORE::not Math::GMPq::Rmpq_integer_p($$y)) {
             return Sidef::Types::Number::Complex->new($x)->pow($y);
         }
 
@@ -468,7 +477,7 @@ package Sidef::Types::Number::Number {
         if (defined $y) {
 
             if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
-                return $ZERO;
+                return (ZERO);
             }
 
             _valid($y);
@@ -785,7 +794,7 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return $ZERO;
+            return (ZERO);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
             if (Math::GMPq::Rmpq_sgn($$x) >= 0) {
@@ -893,10 +902,10 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid($y);
         if (Math::GMPq::Rmpq_equal($$x, $$y)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -904,10 +913,10 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid($y);
         if (Math::GMPq::Rmpq_equal($$x, $$y)) {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
     }
 
@@ -915,15 +924,15 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return $MONE;
+            return (MONE);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return $ONE;
+            return (ONE);
         }
 
         _valid($y);
         my $cmp = Math::GMPq::Rmpq_cmp($$x, $$y);
-        !$cmp ? $ZERO : $cmp < 0 ? $MONE : $ONE;
+        !$cmp ? (ZERO) : $cmp < 0 ? (MONE) : (ONE);
     }
 
     sub acmp {
@@ -951,26 +960,26 @@ package Sidef::Types::Number::Number {
           : $yn;
 
         my $cmp = Math::GMPq::Rmpq_cmp($a1, $a2);
-        !$cmp ? $ZERO : $cmp < 0 ? $MONE : $ONE;
+        !$cmp ? (ZERO) : $cmp < 0 ? (MONE) : (ONE);
     }
 
     sub gt {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return state $x = Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return state $x = Sidef::Types::Bool::Bool->true;
+            return (Sidef::Types::Bool::Bool::TRUE);
         }
 
         _valid($y);
 
         if (Math::GMPq::Rmpq_cmp($$x, $$y) > 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -978,19 +987,19 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return state $x = Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return state $x = Sidef::Types::Bool::Bool->true;
+            return (Sidef::Types::Bool::Bool::TRUE);
         }
 
         _valid($y);
 
         if (Math::GMPq::Rmpq_cmp($$x, $$y) >= 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -998,19 +1007,19 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return state $x = Sidef::Types::Bool::Bool->true;
+            return (Sidef::Types::Bool::Bool::TRUE);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return state $x = Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         _valid($y);
 
         if (Math::GMPq::Rmpq_cmp($$x, $$y) < 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1018,49 +1027,49 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf') {
-            return state $x = Sidef::Types::Bool::Bool->true;
+            return (Sidef::Types::Bool::Bool::TRUE);
         }
         elsif (ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return state $x = Sidef::Types::Bool::Bool->false;
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         _valid($y);
 
         if (Math::GMPq::Rmpq_cmp($$x, $$y) <= 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_zero {
         my ($x) = @_;
         if (CORE::not Math::GMPq::Rmpq_sgn($$x)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_one {
         my ($x) = @_;
-        if (Math::GMPq::Rmpq_equal($$x, $$ONE)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+        if (Math::GMPq::Rmpq_equal($$x, ${(ONE)})) {
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_positive {
         my ($x) = @_;
         if (Math::GMPq::Rmpq_sgn($$x) > 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1069,10 +1078,10 @@ package Sidef::Types::Number::Number {
     sub is_negative {
         my ($x) = @_;
         if (Math::GMPq::Rmpq_sgn($$x) < 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1092,64 +1101,54 @@ package Sidef::Types::Number::Number {
         }
     }
 
-    sub _is_int {
-        my ($x) = @_;
-
-        my $dz = Math::GMPz::Rmpz_init();
-        Math::GMPq::Rmpq_get_den($dz, $x);
-
-        state $one_z = Math::GMPz::Rmpz_init_set_ui(1);
-        CORE::not Math::GMPz::Rmpz_cmp($dz, $one_z);
-    }
-
     sub is_int {
         my ($x) = @_;
-        if (_is_int($$x)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+        if (Math::GMPq::Rmpq_integer_p($$x)) {
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_real {
         my ($x) = @_;
-        state $z = Sidef::Types::Bool::Bool->true;
+        (Sidef::Types::Bool::Bool::TRUE);
     }
 
     sub is_even {
         my ($x) = @_;
 
-        if (CORE::not _is_int($$x)) {
-            return state $z = Sidef::Types::Bool::Bool->false;
+        if (CORE::not Math::GMPq::Rmpq_integer_p($$x)) {
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $nz = Math::GMPz::Rmpz_init();
         Math::GMPq::Rmpq_get_num($nz, $$x);
 
         if (Math::GMPz::Rmpz_even_p($nz)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_odd {
         my ($x) = @_;
 
-        if (CORE::not _is_int($$x)) {
-            return state $z = Sidef::Types::Bool::Bool->false;
+        if (CORE::not Math::GMPq::Rmpq_integer_p($$x)) {
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $nz = Math::GMPz::Rmpz_init();
         Math::GMPq::Rmpq_get_num($nz, $$x);
 
         if (Math::GMPz::Rmpz_odd_p($nz)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1157,14 +1156,17 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid($y);
 
+        return Sidef::Types::Bool::Bool::FALSE
+          if Math::GMPq::Rmpq_sgn($$y) == 0;
+
         my $q = Math::GMPq::Rmpq_init();
         Math::GMPq::Rmpq_div($q, $$x, $$y);
 
-        if (_is_int($q)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+        if (Math::GMPq::Rmpq_integer_p($q)) {
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1172,27 +1174,30 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid($y);
 
+        return Sidef::Types::Bool::Bool::FALSE
+          if Math::GMPq::Rmpq_sgn($$x) == 0;
+
         my $q = Math::GMPq::Rmpq_init();
         Math::GMPq::Rmpq_div($q, $$y, $$x);
 
-        if (_is_int($q)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+        if (Math::GMPq::Rmpq_integer_p($q)) {
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
     sub is_inf {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_nan {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_ninf {
-        state $x = Sidef::Types::Bool::Bool->false;
+        (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub max {
@@ -1264,7 +1269,7 @@ package Sidef::Types::Number::Number {
         Math::GMPz::Rmpz_set_q($z, $$x);
         Math::GMPz::Rmpz_abs($z, $z);
         my $digit = (split(//, Math::GMPz::Rmpz_get_str($z, 10)))[Math::GMPq::Rmpq_get_d($$y)];
-        defined($digit) ? _new_uint($digit) : $MONE;
+        defined($digit) ? _new_uint($digit) : (MONE);
     }
 
     sub length {
@@ -1281,7 +1286,7 @@ package Sidef::Types::Number::Number {
 
     sub floor {
         my ($x) = @_;
-        _is_int($$x) && return $x;
+        Math::GMPq::Rmpq_integer_p($$x) && return $x;
 
         if (Math::GMPq::Rmpq_sgn($$x) > 0) {
             my $z = Math::GMPz::Rmpz_init();
@@ -1298,7 +1303,7 @@ package Sidef::Types::Number::Number {
 
     sub ceil {
         my ($x) = @_;
-        _is_int($$x) && return $x;
+        Math::GMPq::Rmpq_integer_p($$x) && return $x;
 
         if (Math::GMPq::Rmpq_sgn($$x) > 0) {
             my $z = Math::GMPz::Rmpz_init();
@@ -1316,14 +1321,14 @@ package Sidef::Types::Number::Number {
     sub inc {
         my ($x) = @_;
         my $r = Math::GMPq::Rmpq_init();
-        Math::GMPq::Rmpq_add($r, $$x, $$ONE);
+        Math::GMPq::Rmpq_add($r, $$x, ${(ONE)});
         bless \$r, __PACKAGE__;
     }
 
     sub dec {
         my ($x) = @_;
         my $r = Math::GMPq::Rmpq_init();
-        Math::GMPq::Rmpq_sub($r, $$x, $$ONE);
+        Math::GMPq::Rmpq_sub($r, $$x, ${(ONE)});
         bless \$r, __PACKAGE__;
     }
 
@@ -1374,7 +1379,7 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
 
         if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
-            return $ONE;
+            return (ONE);
         }
 
         _valid($y);
@@ -1387,7 +1392,7 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid($y);
 
-        if (_is_int($$x) and _is_int($$y)) {
+        if (Math::GMPq::Rmpq_integer_p($$x) and Math::GMPq::Rmpq_integer_p($$y)) {
             my $r      = Math::GMPz::Rmpz_init();
             my $yz     = _as_int($y);
             my $sign_y = Math::GMPz::Rmpz_sgn($yz);
@@ -1402,7 +1407,7 @@ package Sidef::Types::Number::Number {
             Math::MPFR::Rmpfr_fmod($r, _as_float($x), $yf, $ROUND);
             my $sign = Math::MPFR::Rmpfr_sgn($r);
             if (CORE::not $sign) {
-                return $ZERO;
+                return (ZERO);
             }
             elsif (($sign > 0) ne (Math::MPFR::Rmpfr_sgn($yf) > 0)) {
                 Math::MPFR::Rmpfr_add($r, $r, $yf, $ROUND);
@@ -1564,15 +1569,19 @@ package Sidef::Types::Number::Number {
         _mpz2rat($r);
     }
 
-    # Correct up to a maximum value of 341,550,071,728,320
+    # By default, the test is correct up to a maximum value of 341,550,071,728,320
     # See: https://en.wikipedia.org/wiki/Miller%E2%80%93Rabin_primality_test#Deterministic_variants_of_the_test
     sub is_prime {
-        my ($x) = @_;
-        if (Math::GMPz::Rmpz_probab_prime_p(_as_int($x), 7) > 0) {
-            state $z = Sidef::Types::Bool::Bool->true;
+        my ($x, $k) = @_;
+        if (
+            Math::GMPz::Rmpz_probab_prime_p(_as_int($x), defined($k)
+                                            ? do { _valid($k); CORE::int Math::GMPq::Rmpq_get_d($$k) }
+                                            : 7) > 0
+          ) {
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1586,18 +1595,18 @@ package Sidef::Types::Number::Number {
     sub is_square {
         my ($x) = @_;
 
-        if (CORE::not _is_int($$x)) {
-            return state $z = Sidef::Types::Bool::Bool->false;
+        if (CORE::not Math::GMPq::Rmpq_integer_p($$x)) {
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $nz = Math::GMPz::Rmpz_init();
         Math::GMPq::Rmpq_get_num($nz, $$x);
 
         if (Math::GMPz::Rmpz_perfect_square_p($nz)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1606,18 +1615,18 @@ package Sidef::Types::Number::Number {
     sub is_power {
         my ($x) = @_;
 
-        if (CORE::not _is_int($$x)) {
-            return state $z = Sidef::Types::Bool::Bool->false;
+        if (CORE::not Math::GMPq::Rmpq_integer_p($$x)) {
+            return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $nz = Math::GMPz::Rmpz_init();
         Math::GMPq::Rmpq_get_num($nz, $$x);
 
         if (Math::GMPz::Rmpz_perfect_power_p($nz)) {
-            state $z = Sidef::Types::Bool::Bool->true;
+            (Sidef::Types::Bool::Bool::TRUE);
         }
         else {
-            state $z = Sidef::Types::Bool::Bool->false;
+            (Sidef::Types::Bool::Bool::FALSE);
         }
     }
 
@@ -1733,9 +1742,7 @@ package Sidef::Types::Number::Number {
 
     sub complex {
         my ($x, $y) = @_;
-
         if (defined $y) {
-            _valid($y);
             Sidef::Types::Number::Complex->new($x, $y);
         }
         else {
@@ -1757,7 +1764,7 @@ package Sidef::Types::Number::Number {
         _valid($y);
 
         my @array;
-        if (CORE::not defined($step) and _is_int($$x) and _is_int($$y)) {
+        if (CORE::not defined($step) and Math::GMPq::Rmpq_integer_p($$x) and Math::GMPq::Rmpq_integer_p($$y)) {
             foreach my $i (Math::GMPq::Rmpq_get_d($$x) .. Math::GMPq::Rmpq_get_d($$y)) {
                 my $n = Math::GMPq::Rmpq_init();
                 Math::GMPq::Rmpq_set_si($n, $i, 1);
@@ -1767,7 +1774,7 @@ package Sidef::Types::Number::Number {
         else {
 
             if (CORE::not defined $step) {
-                $step = $ONE;
+                $step = (ONE);
             }
             else {
                 _valid($step);
@@ -1797,7 +1804,7 @@ package Sidef::Types::Number::Number {
 
         if (CORE::not defined $step) {
             _valid($y);
-            $step = $ONE;
+            $step = (ONE);
         }
         else {
             _valid($y, $step);
@@ -1845,7 +1852,7 @@ package Sidef::Types::Number::Number {
         Sidef::Types::Range::RangeNumber->__new__(
                                                   from => $$from,
                                                   to   => $$to,
-                                                  step => (defined($step) ? $$step : $$ONE),
+                                                  step => (defined($step) ? $$step : ${(ONE)}),
                                                  );
     }
 
@@ -1867,7 +1874,7 @@ package Sidef::Types::Number::Number {
             Math::GMPq::Rmpq_neg($r, $$step);
             $r;
           }
-          : $$MONE;
+          : ${(MONE)};
 
         Sidef::Types::Range::RangeNumber->__new__(
                                                   from => $$from,
@@ -1881,7 +1888,7 @@ package Sidef::Types::Number::Number {
 
         defined($to)
           ? $from->to($to, $step)
-          : $ZERO->to($from->dec);
+          : (ZERO)->to($from->dec);
     }
 
     sub rand {
@@ -1910,6 +1917,8 @@ package Sidef::Types::Number::Number {
         }
     }
 
+    *irand = \&rand_int;
+
     sub of {
         my ($x, $obj) = @_;
         ref($obj) eq 'Sidef::Types::Block::Block'
