@@ -5,9 +5,12 @@ package Sidef::Types::Range::RangeNumber {
       Sidef::Object::Object
       );
 
-    require Sidef::Types::Number::Number;
+    use overload
+      '@{}' => \&to_a,
+      q{""} => \&dump;
 
-    use overload '@{}' => \&to_a;
+    use Sidef::Types::Bool::Bool;
+    use Sidef::Types::Number::Number;
 
     sub new {
         my (undef, $from, $to, $step) = @_;
@@ -88,14 +91,14 @@ package Sidef::Types::Range::RangeNumber {
         my ($min, $max) = ($self->{step} > 0 ? ($self->{from}, $self->{to}) : ($self->{to}, $self->{from}));
         my $step = $self->{step};
 
-        Sidef::Types::Bool::Bool->new(
-                                      $value >= $min and $value <= $max
-                                        and (
-                                               $step == 1 ? 1
-                                             : $step > 0 ? (int(($value - $min) / $step) * $step == ($value - $min))
-                                             :             (int(($value - $max) / $step) * $step == ($value - $max))
-                                            )
-                                     );
+        (
+         $value >= $min and $value <= $max
+           and (
+                  $step == 1 ? 1
+                : $step > 0 ? (int(($value - $min) / $step) * $step == ($value - $min))
+                :             (int(($value - $max) / $step) * $step == ($value - $max))
+               )
+        ) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     *contain  = \&contains;
@@ -112,8 +115,8 @@ package Sidef::Types::Range::RangeNumber {
         if (    $step == 1
             and $to <   (-1 >> 1)
             and $from < (-1 >> 1)
-            and (ref($from) ? Sidef::Types::Number::Number::_is_int($from) : 1)
-            and (ref($to)   ? Sidef::Types::Number::Number::_is_int($to)   : 1)) {
+            and (ref($from) ? Math::GMPq::Rmpq_integer_p($from) : 1)
+            and (ref($to)   ? Math::GMPq::Rmpq_integer_p($to)   : 1)) {
             foreach my $i ($from .. $to) {
                 if (defined(my $res = $code->_run_code(Sidef::Types::Number::Number::_new_int($i)))) {
                     return $res;
@@ -150,8 +153,8 @@ package Sidef::Types::Range::RangeNumber {
         if (    $step == 1
             and $to <   (-1 >> 1)
             and $from < (-1 >> 1)
-            and (ref($from) ? Sidef::Types::Number::Number::_is_int($from) : 1)
-            and (ref($to)   ? Sidef::Types::Number::Number::_is_int($to)   : 1)) {
+            and (ref($from) ? Math::GMPq::Rmpq_integer_p($from) : 1)
+            and (ref($to)   ? Math::GMPq::Rmpq_integer_p($to)   : 1)) {
             foreach my $i ($from .. $to) {
                 push @values, $code->run(Sidef::Types::Number::Number::_new_int($i));
             }
@@ -183,8 +186,8 @@ package Sidef::Types::Range::RangeNumber {
         if (    $step == 1
             and $to <   (-1 >> 1)
             and $from < (-1 >> 1)
-            and (ref($from) ? Sidef::Types::Number::Number::_is_int($from) : 1)
-            and (ref($to)   ? Sidef::Types::Number::Number::_is_int($to)   : 1)) {
+            and (ref($from) ? Math::GMPq::Rmpq_integer_p($from) : 1)
+            and (ref($to)   ? Math::GMPq::Rmpq_integer_p($to)   : 1)) {
             foreach my $i ($from .. $to) {
                 my $num = Sidef::Types::Number::Number::_new_int($i);
                 push(@values, $num) if $code->run($num);
@@ -220,8 +223,8 @@ package Sidef::Types::Range::RangeNumber {
         if (    $step == 1
             and $to <   (-1 >> 1)
             and $from < (-1 >> 1)
-            and (ref($from) ? Sidef::Types::Number::Number::_is_int($from) : 1)
-            and (ref($to)   ? Sidef::Types::Number::Number::_is_int($to)   : 1)) {
+            and (ref($from) ? Math::GMPq::Rmpq_integer_p($from) : 1)
+            and (ref($to)   ? Math::GMPq::Rmpq_integer_p($to)   : 1)) {
             foreach my $i ($from + 1 .. $to) {
                 my $num = Sidef::Types::Number::Number::_new_int($i);
                 $value = $code->run($value, $num);
@@ -276,13 +279,17 @@ package Sidef::Types::Range::RangeNumber {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '=='} = sub {
             my ($r1, $r2) = @_;
-            Sidef::Types::Bool::Bool->new(    ref($r1) eq ref($r2)
-                                          and $r1->{from} == $r2->{from}
-                                          and $r1->{to} == $r2->{to}
-                                          and $r1->{step} == $r2->{step});
+            (ref($r1) eq ref($r2) and $r1->{from} == $r2->{from} and $r1->{to} == $r2->{to} and $r1->{step} == $r2->{step})
+              ? (Sidef::Types::Bool::Bool::TRUE)
+              : (Sidef::Types::Bool::Bool::FALSE);
         };
     }
 
+    sub dump {
+        my ($self) = @_;
+        Sidef::Types::String::String->new("RangeNum($self->{from}, $self->{to}, $self->{step})");
+    }
+
 }
 
 1;
